/*
 shield_lpm11162.pde
 Programma per testare lo shield per LPM11162, vengono
 attivati due relè mentre viene emesso il messaggio vocale
 corrispondente
 
 Vengono utilizzati i seguenti pin
 Pin +5V         -> Alimentazione
 Pin GND         -> Alimentazione
 Pin Vin         -> Alimentazione Motori
 Pin Digital 2   -> Pin 2 RESET modulo LPM11162
 Pin Digital 3   -> Pin 3 TX modulo LPM11162
 Pin Digital 4   -> Pin 4 RX modulo LPM11162
 Pin Digital 5   -> Pin 5 BUSY modulo LPM11162
 Pin Digital 6   -> Pin 6 led su shield LPM11162
 Pin Digital 8   -> Attiva relè 1
 Pin Digital 9   -> Attiva relè 2
 Pin Digital 10  -> Pulsante su ProShield
 Pin Digital 13  -> Pin 13 led su ProShield
 
 Creato il 27/06/2012
 da Adriano Gandolfo <http://www.adrirobot.it>
 This example code is in the public domain.
 */


#include <SoftwareSerial.h>
#include <LPM11162.h>

LPM11162 audio(3,4,2);   //Arduino tx, Arduino rx, reset
const int led_1 = 6;     // Pin 6 Led su shield LPM11162
const int led_2 =  13;   // Pin 13 led su ProShield
const int rele_1 =  8;   // Pin 8 Relè 1
const int rele_2 =  9;   // Pin 9 Relè 2
const int pulsante =  10;   // Pulsante su ProShield

// variabile:
int buttonState = 0;   // variabile per lettura stato pulsante

void setup(){
  pinMode (led_1, OUTPUT);  
  pinMode (led_2, OUTPUT);
  pinMode (rele_1, OUTPUT);
  pinMode (rele_2, OUTPUT);
  pinMode (pulsante, INPUT);

  if ( audio.synch() )
  {
    audio.bridge();
  }
  audio.begin(9600);
}

void loop()

{
  // legge lo stato del pulsante:
  digitalWrite(rele_1, HIGH);
  digitalWrite(rele_2, HIGH);
  digitalWrite(led_1, LOW);
  digitalWrite(led_2, LOW);
  delay (1000);
  buttonState = digitalRead(pulsante);

  // Controlla se il pulsante è premuto.
  // se si il valore di buttonState è HIGH:
  if (buttonState == HIGH) 
  {     
    digitalWrite(led_1, HIGH);   // Accende led Rosso su shield LPM11162
    digitalWrite(rele_1, LOW);
    audio.volume(50);
    //delay (500);
    audio.play("rele1.wav"); // Pronuncia frase
    delay (2000);
    digitalWrite(rele_2, LOW);
    audio.play("rele2.wav"); // Pronuncia frase
    delay (2000);
    digitalWrite(led_2, HIGH);
    //delay (2000);
    digitalWrite(rele_1, HIGH);
    digitalWrite(rele_2, HIGH);
    audio.play("emergenza.wav"); // Pronuncia frase
    delay (3000);
  } 
  else {
    // turn LED off:
    digitalWrite(led_1, LOW);
    digitalWrite(led_2, LOW);
  }
}


